import { Subject } from 'rxjs';
import { DashboardViewBase } from '@/studio-core';
import EAMSparePartsGroupService from '@/service/eamspare-parts-group/eamspare-parts-group-service';
import EAMSparePartsGroupAuthService from '@/authservice/eamspare-parts-group/eamspare-parts-group-auth-service';
import PortalViewEngine from '@engine/view/portal-view-engine';
import EAMSparePartsGroupUIService from '@/uiservice/eamspare-parts-group/eamspare-parts-group-ui-service';

/**
 * 备件包数据看板视图视图基类
 *
 * @export
 * @class EAMSparePartsGroupDashboardViewBase
 * @extends {DashboardViewBase}
 */
export class EAMSparePartsGroupDashboardViewBase extends DashboardViewBase {
    /**
     * 视图对应应用实体名称
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    protected appDeName: string = 'eamsparepartsgroup';

    /**
     * 应用实体主键
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    protected appDeKey: string = 'eamsparepartsgroupid';

    /**
     * 应用实体主信息
     *
     * @protected
     * @type {string}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    protected appDeMajor: string = 'eamsparepartsgroupname';

    /**
     * 实体服务对象
     *
     * @type {EAMSparePartsGroupService}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    protected appEntityService: EAMSparePartsGroupService = new EAMSparePartsGroupService;

    /**
     * 实体权限服务对象
     *
     * @type EAMSparePartsGroupUIService
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    public appUIService: EAMSparePartsGroupUIService = new EAMSparePartsGroupUIService(this.$store);


    /**
     * 计数器服务对象集合
     *
     * @protected
     * @type {Array<*>}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */    
    protected counterServiceArray: Array<any> = [];

    /**
     * 视图模型数据
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    protected model: any = {
        srfCaption: 'entities.eamsparepartsgroup.views.dashboardview.caption',
        srfTitle: 'entities.eamsparepartsgroup.views.dashboardview.title',
        srfSubTitle: 'entities.eamsparepartsgroup.views.dashboardview.subtitle',
        dataInfo: ''
    }

    /**
     * 容器模型
     *
     * @protected
     * @type {*}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    protected containerModel: any = {
        view_dashboard: { name: 'dashboard', type: 'DASHBOARD' },
    };


	/**
     * 视图唯一标识
     *
     * @protected
     * @type {string}
     * @memberof ViewBase
     */
	protected viewtag: string = 'd12c50a13617e683c9ee4efee5f46906';


    /**
     * 视图引擎
     *
     * @public
     * @type {Engine}
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    public engine: PortalViewEngine = new PortalViewEngine();

    /**
     * 引擎初始化
     *
     * @public
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    public engineInit(): void {
        this.engine.init({
            view: this,
            dashboard: this.$refs.dashboard,
            keyPSDEField: 'eamsparepartsgroup',
            majorPSDEField: 'eamsparepartsgroupname',
            isLoadDefault: true,
        });
    }

    /**
     * dashboard 部件 load 事件
     *
     * @param {*} [args={}]
     * @param {*} $event
     * @memberof EAMSparePartsGroupDashboardViewBase
     */
    public dashboard_load($event: any, $event2?: any): void {
        this.engine.onCtrlEvent('dashboard', 'load', $event);
    }


}